@@ -35,6 +35,7 @@ from .gadget import Gadget, GadgetType
 from binascii import hexlify, unhexlify
 from struct import pack
 import re
+import multiprocessing as mp
 import struct
 import sys
 import capstone
@@ -215,7 +216,8 @@ class Ropper(object):
         disassembler = self.__getCs(binary.arch)
         toReturn = []
         code = bytearray(section.bytes)
-        offset = section.offset
+        # TODO: Another solution should be used here. This is a hack for compatibility reasons. to resolve the gadget address calculation of segments of elf files have a different base address if calculated segment.virtualAddress - segment.offset 
+        offset = section.offset - (binary.originalImageBase - (section.virtualAddress - section.offset))
         for match in re.finditer(opcode, code):
             opcodeGadget = Gadget(binary.checksum, section.name, binary.arch)
 
@@ -252,13 +254,14 @@ class Ropper(object):
         return toReturn
 
     def _searchPopPopRet(self, section, binary):
-        if binary.arch != x86:
+        if not isinstance(binary.arch, x86.__class__ ):
             raise NotSupportedError(
                 'Wrong architecture, \'pop pop ret\' is only supported on x86')
 
         disassembler = self.__getCs(binary.arch)
         code = section.bytes
-        offset = section.offset
+        # TODO: Another solution should be used here. This is a hack for compatibility reasons. to resolve the gadget address calculation of segments of elf files have a different base address if calculated segment.virtualAddress - segment.offset 
+        offset = section.offset - (binary.originalImageBase - (section.virtualAddress - section.offset))
         toReturn = []
         pprs = binary.arch.pprs
         for ppr in pprs:
@@ -272,10 +275,10 @@ class Ropper(object):
         return toReturn
 
     def searchGadgets(self, binary, instructionCount=5, gtype=GadgetType.ALL, multiprocessing=False):
-        Gadget.IMAGE_BASES[binary.checksum] = binary.imageBase
+        if Gadget.IMAGE_BASES.get(binary.checksum) == None:
+            Gadget.IMAGE_BASES[binary.checksum] = binary.originalImageBase
         gadgets = []
         for section in binary.executableSections:
-            vaddr = binary.imageBase
 
             if self.__callback:
                 self.__callback(section, None, 0)
@@ -283,6 +286,8 @@ class Ropper(object):
             if not multiprocessing:
                 newGadgets = self._searchGadgetsSingle(section=section, binary=binary, instruction_count=instructionCount, gtype=gtype)
             else:
+                if mp.get_start_method() != 'fork':
+                    mp.set_start_method('fork', force=True)
                 newGadgets = self._searchGadgetsForked(section=section, binary=binary, instruction_count=instructionCount, gtype=gtype)
 
             gadgets.extend(newGadgets)
@@ -294,7 +299,7 @@ class Ropper(object):
         toReturn = []
         code = bytes(bytearray(section.bytes))
         # TODO: Another solution should be used here. This is a hack for compatibility reasons. to resolve the gadget address calculation of segments of elf files have a different base address if calculated segment.virtualAddress - segment.offset 
-        offset = section.offset - (binary.imageBase - (section.virtualAddress - section.offset))
+        offset = section.offset - (binary.originalImageBase - (section.virtualAddress - section.offset))
         #offset = section.offset
 
         arch = binary.arch
@@ -367,7 +372,7 @@ class Ropper(object):
             ending_queue.put(None)
 
         # TODO: Another solution should be used here. This is a hack for compatibility reasons. to resolve the gadget address calculation of segments of elf files have a different base address if calculated segment.virtualAddress - segment.offset 
-        offset = section.offset - (binary.imageBase - (section.virtualAddress - section.offset))
+        offset = section.offset - (binary.originalImageBase - (section.virtualAddress - section.offset))
 
         for cpu in range(process_count):
             processes.append(Process(target=self.__gatherGadgetsByEndings, args=(tmp_code, arch, binary.checksum, section.name, offset, ending_queue, gadget_queue, instruction_count), name="GadgetSearch%d"%cpu))
